@@ -6,7 +6,7 @@ use Carp;
 use Moo;
 use Types::Standard qw/Str Num Int ArrayRef/;
 
-our $VERSION = '0.0.4'; # VERSION
+our $VERSION = '0.0.5'; # VERSION
 # ABSTRACT: Statistics::Cook - calculate cook distance of Least squares line fit
 
 
@@ -169,7 +169,7 @@ sub cooks_distance {
 sub N {
   my ($self, $num, $N) = @_;
   $N ||= 50;
-  my @nums = sort { $a <=> $b } @$num;
+  my @nums = sort { $b <=> $a } @$num;
   my $sum = sum(@nums);
   my $tmp = 0;
   for my $i (0..$#nums) {
@@ -192,7 +192,7 @@ Statistics::Cook - Statistics::Cook - calculate cook distance of Least squares l
 
 =head1 VERSION
 
-version 0.0.4
+version 0.0.5
 
 =head1 SYNOPSIS
 
